@@ -1,3 +1,18 @@
+# Copyright Contributors to the Rez project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 from __future__ import print_function
 
 from rez.utils.execution import create_forwarding_script
@@ -158,8 +173,10 @@ class Suite(object):
                 variant = context.get_resolved_package(in_resolve.name)
                 if variant:
                     overlap = (variant.version in in_resolve.range)
-                    return ((in_resolve.conflict and not overlap)
-                            or (overlap and not in_resolve.conflict))
+                    return (
+                        (in_resolve.conflict and not overlap)
+                        or (overlap and not in_resolve.conflict)
+                    )
                 else:
                     return in_resolve.conflict
 
@@ -758,19 +775,3 @@ def _FWD__invoke_suite_tool_alias(context_name, tool_name, prefix_char=None,
     w._init(suite_path, context_name, context, tool_name, prefix_char)
     retcode = w.run(*(_cli_args or []))
     sys.exit(retcode)
-
-
-# Copyright 2013-2016 Allan Johns.
-#
-# This library is free software: you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation, either
-# version 3 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library.  If not, see <http://www.gnu.org/licenses/>.
